﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;
using UnityEngine.Networking;

public class GameOverManager : MonoBehaviour {

	public GameOverThemeManager themeManager;
    public GameOverLoginManager loginManager;

    public HighScoreManager highScoreManager;

	public GameObject bgScrollObj;

	public GameObject overlayObj;
	public Image overlayImage;
	public float overlayAlpha = 1.0f;
	public bool overlayFadeIn = false;
	public bool overlayFadeOut = false;

	public Image backBtnImage;
	public Image newGameBtnImage;
	public Image logoBtnImage;

	public Image containerImage;

	public Text titleText;
	public Text titleShadowText;

	public Text scoreSubtitleText;
	public Text scoreSubtitleShadowText;

	public Text scoreText;
	public Text scoreShadowText;

	public Text wordsMadeSubtitleText;
	public Text wordsMadeSubtitleShadowText;
	public Text wordsMadeText;
	public Text wordsMadeShadowText;

	public string tempScore;
	public string wordsMade;

	public string current_theme;

    public InputField nameInput;
    public Text nameInputText;
    public Button saveOfflineButton;
    public Button saveOnlineButton;

    public Button loggedInButton;
    public Text loggedInText;

    public GameObject logoutPopupObj;
	public GameObject needLoginPopup;
	public GameObject needNamePopup;
    public GameObject offlineScorePopup;
    public GameObject onlineScorePopup;

    public bool moveScene = false;

    public bool loggedIn = false;

    public AudioSource gameOverAudio;

    public AudioClip gameOverCla;
    public AudioClip gameOverTec;
    public AudioClip gameOverBam;
    public AudioClip gameOverDar;
    public AudioClip gameOverCan;
    public AudioClip gameOverPas;

    public GameObject gameOverProfileImageObj;
    public RawImage gameOverProfileImage;

    public Text prevScoreText;
    public Text prevScoreTextShadow;

    public GameObject adObject;
    public Image adImage;
    public Sprite adImg1;
    public Sprite adImg2;
    public Sprite adImg3;
    public Sprite adImg4;
    public Sprite adImg5;
    public Sprite adImg6;
    public int curAd = 1;

	// Use this for initialization
	void Start () {

        if (PlayerPrefs.GetInt("free_mode") == 1)
        {
            if (PlayerPrefs.GetInt("preview_mode") == 1)
            {
                PlayerPrefs.SetString("cur_theme", "classic");
                PlayerPrefs.SetInt("preview_mode", 0);
                saveOnlineButton.enabled = false;
                Color tmpCol;
                tmpCol = saveOnlineButton.image.color;
                tmpCol.a = 0.5f;
                saveOnlineButton.image.color = tmpCol;
            }

            if(PlayerPrefs.GetInt("freeHighScore")==1){
                titleText.text = "congratulations!";
                titleShadowText.text = "congratulations!";
                scoreSubtitleText.text = "you reached";
                scoreSubtitleShadowText.text = "you reached";
                PlayerPrefs.SetInt("freeHighScore", 0);
            } else {
                titleText.text = "game over";
                titleShadowText.text = "game over";
                scoreSubtitleText.text = "your score was";
                scoreSubtitleShadowText.text = "your score was";
            }
        }

        gameOverProfileImageObj.SetActive(false);

		checkTheme();
        checkLoggedIn();

		fadeOutOverlay();
		fetchAndDisplayInfo();

        if (PlayerPrefs.GetInt("free_mode") == 1)
        {
            adObject.SetActive(true);
            StartCoroutine(changeAd());


            prevScoreText.text = "";
            prevScoreTextShadow.text = "";

            Color tmpCol = saveOnlineButton.image.color;
            tmpCol.a = 0.5f;
            saveOnlineButton.image.color = tmpCol;
            saveOnlineButton.enabled = false;
            loggedInButton.gameObject.SetActive(false);
        }
        else
        {
            adObject.SetActive(false);
            if (loggedIn)
            {

                //      string tempString = "username=" + PlayerPrefs.GetString("tempUsername") + "&score=" + scoreText.text + "&wordlist=notyet";
                StartCoroutine(CheckPreviousOnlineScore());


            }
        }

        prevScoreText.text = "";
        prevScoreTextShadow.text = "";
	}

    public IEnumerator changeAd()
    {
        while (true)
        {
            curAd++;
            if (curAd == 7) curAd = 1;
            if (curAd == 1) adImage.sprite = adImg1;
            if (curAd == 2) adImage.sprite = adImg2;
            if (curAd == 3) adImage.sprite = adImg3;
            if (curAd == 4) adImage.sprite = adImg4;
            if (curAd == 5) adImage.sprite = adImg5;
            if (curAd == 1) adImage.sprite = adImg6;

            yield return new WaitForSeconds(5.0f);
        }

    }
	
	// Update is called once per frame
	void Update () {

		checkOverlay();

	}

    public void logoutConfirm() {

        logoutPopupObj.SetActive(false);
        PlayerPrefs.SetInt("loggedIn", 0);
        PlayerPrefs.SetString("tempUsername", "");
        checkLoggedIn();

    }

    public void logoutCancel() {

        logoutPopupObj.SetActive(false);

    }

    public void offlineCancel()
    {

        offlineScorePopup.SetActive(false);

    }

    public void onlineCancel()
    {

        onlineScorePopup.SetActive(false);

    }

    public void loggedInPressed() {

        checkLoggedIn();

        if (loggedIn)
        {
            logoutPopupObj.SetActive(true);
        } else {
            loginManager.loginPopupObj.SetActive(true);
        }

    }

    void checkLoggedIn() {

        if(PlayerPrefs.GetInt("loggedIn")==1){
            loggedIn = true;
            loggedInText.text = "logged in as: " + PlayerPrefs.GetString("tempUsername")+ "\n(not you?)";
            //nameInput.interactable = false;
            saveOnlineButton.interactable = true;
            nameInputText.text = PlayerPrefs.GetString("tempUsername");
            Color tmpColor = saveOfflineButton.GetComponent<Image>().color;
            tmpColor.a = 1.0f;
            saveOfflineButton.GetComponent<Image>().color = tmpColor;

            if (PlayerPrefs.GetString("login_type") == "fb")
            {
                string fileName = Application.persistentDataPath + "/" + "fbprofile.png";
                byte[] bytes;
                bytes = System.IO.File.ReadAllBytes(fileName);
                Texture2D tempTex = new Texture2D(1, 1);
                tempTex.LoadImage(bytes);
                gameOverProfileImageObj.SetActive(true);
                gameOverProfileImage.texture = tempTex;
            }

        } else {
            loggedIn = false;
            loggedInText.text = "(not logged in)";
            saveOnlineButton.interactable = false;
            nameInput.interactable = true;
            nameInputText.text = "";
            Color tmpColor = saveOfflineButton.GetComponent<Image>().color;
            tmpColor.a = 0.5f;
            saveOfflineButton.GetComponent<Image>().color = tmpColor;
            logoutPopupObj.SetActive(false);
        }

    }

    public void saveScoreOnline () {

        checkLoggedIn();

        if(loggedIn){
            
            string tempString = "name="+PlayerPrefs.GetString("tempUsername")+"&score="+scoreText.text+"&wordlist=notyet";
            StartCoroutine(TrySaveScoreOnline(tempString));

        } else {

            needLoginPopup.SetActive(true);

        }

    }

    public void saveScoreOffline () {

        if (nameInputText.text.Length > 0)
        {
            highScoreManager.SaveHighScore(nameInputText.text, int.Parse(scoreText.text));
            nameInput.interactable = false;
            saveOfflineButton.interactable = false;

            Color tmpColor = nameInput.GetComponent<Image>().color;
            tmpColor.a = 0.5f;
            nameInput.GetComponent<Image>().color = tmpColor;

            tmpColor = saveOfflineButton.GetComponent<Image>().color;
            tmpColor.a = 0.5f;
            saveOfflineButton.GetComponent<Image>().color = tmpColor;

            offlineScorePopup.SetActive(true);

        } else {
            // needNamePopup.SetActive(true);
            Color tmpColor = nameInput.image.color;
            tmpColor.a = 0.7f;
            tmpColor.r = 1.0f;
            tmpColor.g = 0.2f;
            tmpColor.b = 0.2f;
            nameInput.image.color = tmpColor;
            nameInput.Select();
        }

    }

    public void resetField () {
        Color tmpColor = nameInput.image.color;
        tmpColor.a = 1.0f;
        tmpColor.r = 1.0f;
        tmpColor.g = 1.0f;
        tmpColor.b = 1.0f;
        nameInput.image.color = tmpColor;
    }

	public void goBack () {

		fadeInOverlay();

	}

    public void newGamePressed ()
    {
        if (!moveScene)
        {
            moveScene = true;
            SceneManager.LoadScene("02 - Game Scene", LoadSceneMode.Single);
        }
    }

	void fetchAndDisplayInfo () {
		// Fetch info from the game from prefs.
		tempScore = PlayerPrefs.GetString("tempScore");
        wordsMade = PlayerPrefs.GetString("tempWordsMade").Remove(0, 1);
		// Display it.
		scoreText.text = tempScore;
		scoreShadowText.text = tempScore;

        if (PlayerPrefs.GetInt("free_mode") == 1)
        {
            string newWordsMade = "";
            string[] array = wordsMade.Split(',');
            for (int i = 0; i < 5;i++){
                if (i == 4)
                {
                    newWordsMade = newWordsMade + array[i];
                }
                else
                {
                    newWordsMade = newWordsMade + array[i] + ",";
                }
            }
            wordsMade = newWordsMade;

        }

		wordsMadeText.text = wordsMade;
		wordsMadeShadowText.text = wordsMade;



	}

	void checkOverlay () {
		if(overlayFadeIn && overlayAlpha > 0.0f){
			overlayAlpha -= 0.1f;
			setOverlayColor();
		} else if(overlayFadeIn && !(overlayAlpha > 0.0f)){
			overlayFadeIn = false;
			overlayFadeOut = false;
			overlayObj.SetActive(false);
		} else if(overlayFadeOut && overlayAlpha < 1.0f){
			overlayAlpha += 0.1f;
			setOverlayColor();
		} else if(overlayFadeOut && !(overlayAlpha < 1.0f)){
			overlayFadeIn = false;
			overlayFadeOut = false;
			overlayObj.SetActive(true);
            if (!moveScene)
            {
                moveScene = true;
                SceneManager.LoadScene("01 - Main Menu", LoadSceneMode.Single);
            }
		}
	}

	void fadeOutOverlay () {
		overlayObj.SetActive(true);
		overlayFadeIn = true;
		overlayFadeOut = false;
		overlayAlpha = 1.0f;
	}

	void fadeInOverlay () {
		overlayObj.SetActive(true);
		overlayFadeIn = false;
		overlayFadeOut = true;
		overlayAlpha = 0.0f;
	}

	void setOverlayColor () {
		Color tempCol = overlayImage.color;
		tempCol.a = overlayAlpha;
		overlayImage.color = tempCol;
	}

	public void checkTheme () {

        Debug.Log("theme: "+PlayerPrefs.GetString("cur_theme"));

        int volOn = PlayerPrefs.GetInt("volume_on");


		if(PlayerPrefs.GetString("cur_theme").Equals("classic")){

			bgScrollObj.GetComponent<Renderer>().material = themeManager.bgTileClassic;

			backBtnImage.sprite = themeManager.mainMenuImgClassic;
			newGameBtnImage.sprite = themeManager.newGameBtnImgClassic;
			logoBtnImage.sprite = themeManager.logoImgClassic;
			containerImage.sprite = themeManager.containerClassic;

			titleText.color = Color.white;
			titleShadowText.color = Color.black;
			scoreSubtitleText.color = Color.white;
			scoreSubtitleShadowText.color = Color.black;
			scoreText.color = Color.white;
			scoreShadowText.color = Color.black;
			wordsMadeSubtitleText.color = Color.white;
			wordsMadeSubtitleShadowText.color = Color.black;
			wordsMadeText.color = Color.white;
			wordsMadeShadowText.color = Color.black;


            if (volOn == 1)
            {
                gameOverAudio.clip = gameOverCla;
                gameOverAudio.Play();
            }

		} else if(PlayerPrefs.GetString("cur_theme").Equals("techno")){

			bgScrollObj.GetComponent<Renderer>().material = themeManager.bgTileTechno;

			backBtnImage.sprite = themeManager.mainMenuImgTechno;
			newGameBtnImage.sprite = themeManager.newGameBtnImgTechno;
			logoBtnImage.sprite = themeManager.logoImgTechno;
			containerImage.sprite = themeManager.containerTechno;

			titleText.color = Color.white;
			titleShadowText.color = Color.black;
			scoreSubtitleText.color = Color.white;
			scoreSubtitleShadowText.color = Color.black;
			scoreText.color = Color.white;
			scoreShadowText.color = Color.black;
			wordsMadeSubtitleText.color = Color.white;
			wordsMadeSubtitleShadowText.color = Color.black;
			wordsMadeText.color = Color.white;
			wordsMadeShadowText.color = Color.black;

            if (volOn == 1)
            {
                gameOverAudio.clip = gameOverTec;
                gameOverAudio.Play();
            }

		} else if(PlayerPrefs.GetString("cur_theme").Equals("bamboo")){

			bgScrollObj.GetComponent<Renderer>().material = themeManager.bgTileBamboo;

			backBtnImage.sprite = themeManager.mainMenuImgBamboo;
			newGameBtnImage.sprite = themeManager.newGameBtnImgBamboo;
			logoBtnImage.sprite = themeManager.logoImgBamboo;
			containerImage.sprite = themeManager.containerBamboo;

			titleText.color = Color.white;
			titleShadowText.color = Color.black;
			scoreSubtitleText.color = Color.white;
			scoreSubtitleShadowText.color = Color.black;
			scoreText.color = Color.white;
			scoreShadowText.color = Color.black;
			wordsMadeSubtitleText.color = Color.white;
			wordsMadeSubtitleShadowText.color = Color.black;
			wordsMadeText.color = Color.white;
			wordsMadeShadowText.color = Color.black;

            if (volOn == 1)
            {
                gameOverAudio.clip = gameOverBam;
                gameOverAudio.Play();
            }

		} else if(PlayerPrefs.GetString("cur_theme").Equals("night")){

			bgScrollObj.GetComponent<Renderer>().material = themeManager.bgTileNight;

			backBtnImage.sprite = themeManager.mainMenuImgNight;
			newGameBtnImage.sprite = themeManager.newGameBtnImgNight;
			logoBtnImage.sprite = themeManager.logoImgNight;
			containerImage.sprite = themeManager.containerNight;

			titleText.color = Color.white;
			titleShadowText.color = Color.black;
			scoreSubtitleText.color = Color.white;
			scoreSubtitleShadowText.color = Color.black;
			scoreText.color = Color.white;
			scoreShadowText.color = Color.black;
			wordsMadeSubtitleText.color = Color.white;
			wordsMadeSubtitleShadowText.color = Color.black;
			wordsMadeText.color = Color.white;
			wordsMadeShadowText.color = Color.black;

            if (volOn == 1)
            {
                gameOverAudio.clip = gameOverDar;
                gameOverAudio.Play();
            }

		} else if(PlayerPrefs.GetString("cur_theme").Equals("candy")){

			bgScrollObj.GetComponent<Renderer>().material = themeManager.bgTileCandy;

			backBtnImage.sprite = themeManager.mainMenuImgCandy;
			newGameBtnImage.sprite = themeManager.newGameBtnImgCandy;
			logoBtnImage.sprite = themeManager.logoImgCandy;
			containerImage.sprite = themeManager.containerCandy;

			titleText.color = Color.white;
			titleShadowText.color = Color.black;
			scoreSubtitleText.color = Color.white;
			scoreSubtitleShadowText.color = Color.black;
			scoreText.color = Color.white;
			scoreShadowText.color = Color.black;
			wordsMadeSubtitleText.color = Color.white;
			wordsMadeSubtitleShadowText.color = Color.black;
			wordsMadeText.color = Color.white;
			wordsMadeShadowText.color = Color.black;

            if (volOn == 1)
            {
                gameOverAudio.clip = gameOverCan;
                gameOverAudio.Play();
            }

		} else if(PlayerPrefs.GetString("cur_theme").Equals("pastel")){

			bgScrollObj.GetComponent<Renderer>().material = themeManager.bgTilePastel;

			backBtnImage.sprite = themeManager.mainMenuImgPastel;
			newGameBtnImage.sprite = themeManager.newGameBtnImgPastel;
			logoBtnImage.sprite = themeManager.logoImgPastel;
			containerImage.sprite = themeManager.containerPastel;

			titleText.color = Color.black;
			titleShadowText.color = Color.white;
			scoreSubtitleText.color = Color.black;
			scoreSubtitleShadowText.color = Color.white;
			scoreText.color = Color.black;
			scoreShadowText.color = Color.white;
			wordsMadeSubtitleText.color = Color.black;
			wordsMadeSubtitleShadowText.color = Color.white;
			wordsMadeText.color = Color.black;
			wordsMadeShadowText.color = Color.white;
            prevScoreText.color = Color.black;
            prevScoreTextShadow.color = Color.white;

            if (volOn == 1)
            {
                gameOverAudio.clip = gameOverPas;
                gameOverAudio.Play();
            }

		}

	}

    IEnumerator CheckPreviousOnlineScore()
    {

        string tempUrl = "https://onsetsrimes.com/checkChallengerScore.php?username=" + PlayerPrefs.GetString("tempUsername");

        UnityWebRequest www = UnityWebRequest.Get(tempUrl);
        yield return www.Send();

        if (www.isNetworkError)
        {
            Debug.Log(www.error);
        }
        else
        {
            // Show results as text
            Debug.Log(www.downloadHandler.text);

            string resultString = www.downloadHandler.text;

            if (resultString.Length>1)
            {
                prevScoreText.text = "your previous online score was: "+resultString;
                prevScoreTextShadow.text = "your previous online score was: "+ resultString;
            }

            if (int.Parse(resultString)<int.Parse(scoreText.text)){
                titleText.text = "congratulations!";
                titleShadowText.text = "congratulations!";

            } else {
                titleText.text = "game over";
                titleShadowText.text = "game over";
                saveOnlineButton.enabled = false;
                Color tmpCol = saveOnlineButton.image.color;
                tmpCol.a = 0.5f;
                saveOnlineButton.image.color = tmpCol;
            }
         //   saveOnlineButton.enabled = false;
       //     onlineScorePopup.SetActive(true);
        }

    }

    IEnumerator TrySaveScoreOnline(string urlAddon)
    {

        string tempUrl = "https://onsetsrimes.com/AddScoreNew.php?" + urlAddon;

        Debug.Log("tempUrl: " + tempUrl);

        UnityWebRequest www = UnityWebRequest.Get(tempUrl);
        yield return www.Send();

        if (www.isNetworkError)
        {
            Debug.Log(www.error);
        }
        else
        {
            // Show results as text
            Debug.Log(www.downloadHandler.text);


            // Or retrieve results as binary data
            byte[] results = www.downloadHandler.data;

            saveOnlineButton.enabled = false;
            Color tmpCol = saveOnlineButton.image.color;
            tmpCol.a = 0.5f;
            saveOnlineButton.image.color = tmpCol;
            onlineScorePopup.SetActive(true);
        }
    }
}
